function [ N ] = ASME( Sa, Sm, Se, Sy )
%
%  This routine computes the ASME safety factor
%
%    Sa = the alternating stress
%    Sm = the mean stress
%    Se = the endurance strength
%    Sy = the yield strength
%
A = ((Sa/Se)^2) + ((Sm/Sy)^2);
N = sqrt( 1 / A);

end

